@@ -210,6 +210,7 @@ PRIMITIVES = {
     datetime : IsoDateTime,
     date     : IsoDate,
     dict     : Json,
+    list     : Json,
     Exception: ExceptionAdapter,
 }
 
@@ -222,6 +223,7 @@ Types = Union[
     Type[datetime],
     Type[date],
     Type[dict],
+    Type[list],
     Type[Exception],
     Type[NamedTuple],
 ]
@@ -234,6 +236,7 @@ Values = Union[
     datetime,
     date,
     dict,
+    list,
     Exception,
     NamedTuple,
 ]
@@ -818,14 +821,6 @@ def cachew(
     return binder
 
 
-def get_schema(cls: Type) -> Dict[str, Any]:
-    if is_primitive(cls):
-        return {'_': cls} # TODO meh
-    if is_union(cls):
-        return {'_': cls} # TODO meh
-    return cls.__annotations__
-
-
 def cname(func: Callable) -> str:
     # some functions don't have __module__
     mod = getattr(func, '__module__', None) or ''
@@ -857,8 +852,9 @@ class Context(NamedTuple):
             if k in hsig.parameters or 'kwargs' in hsig.parameters
         }
         kwargs = {**defaults, **kwargs}
-        # TODO use inspect.signature to inspect return type annotations at least?
-        return f'cachew: {CACHEW_VERSION}, schema: {get_schema(self.cls)}, dependencies: {self.depends_on(*args, **kwargs)}'
+        binder = NTBinder.make(tp=self.cls)
+        schema = str(binder.columns) # TODO not super nice, but works fine for now
+        return f'cachew: {CACHEW_VERSION}, schema: {schema}, dependencies: {self.depends_on(*args, **kwargs)}'
 
 
 def cachew_wrapper(
@@ -889,7 +885,13 @@ def cachew_wrapper(
     try:
         dbp: Path
         if callable(cache_path):
-            dbp = Path(cache_path(*args, **kwargs))  # type: ignore
+            pp = cache_path(*args, **kwargs) # type: ignore
+            if pp is None:
+                logger.info('[%s]: cache disabled', cn)
+                yield from func(*args, **kwargs)
+                return
+            else:
+                dbp = Path(pp)
         else:
             dbp = Path(cache_path)
 
