@@ -204,6 +204,12 @@ def test_cache_path(tdir):
     # if passed force_file, also treat as file
     assert (tdir / 'name').is_file()
 
+    # treat None as "don't cache" ('factory')
+    fun = cachew(cache_path=lambda *args: None)(orig)
+    assert list(fun()) == [1, 2]
+    assert calls == 6
+    assert list(fun()) == [1, 2]
+    assert calls == 7
     # TODO this won't work at the moment
     # f.write_text('garbage')
     # not sure... on the one hand could just delete the garbage file and overwrite with db
@@ -563,6 +569,7 @@ def test_types(tdir):
         a_dt   : datetime
         a_date : date
         a_json : Dict[str, Any]
+        a_list : List[Any]
         an_exc : Exception
 
     # pylint: disable=no-member
@@ -577,6 +584,7 @@ def test_types(tdir):
         a_dt   =datetime.now(tz=tz),
         a_date =datetime.now().replace(year=2000).date(),
         a_json ={'a': True, 'x': {'whatever': 3.14}},
+        a_list =['aba', 123, None],
         an_exc =RuntimeError('error!', 123),
     )
 
